<?php

namespace App\Controller;

require_once __DIR__ . "/../react-display.php";
use App\Gateway\FormResultGateway;
use \Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Error\SyntaxError;

class SampleFormController {

    private FormResultGateway $gateway;
    private Environment $twig;

    /**
     * @param FormResultGateway $gateway
     */
    public function __construct(FormResultGateway $gateway, Environment $twig)
    {
        $this->gateway = $gateway;
        $this->twig = $twig;
    }


    public function displayForm() {
        send_react_front("views/SampleForm.tsx", []);
    }

    public function submitForm(array $request) {
        $this->gateway->insert($request["name"], $request["description"]);
        $results = ["results" => $this->gateway->listResults()];
        send_react_front("views/DisplayResults.tsx", $results);
    }

    public function displayFormTwig() {
        try {
            echo $this->twig->render('sample_form.html.twig', []);
        } catch (LoaderError | RuntimeError | SyntaxError $e) {
            echo "Twig error: $e";
        }
    }

    public function submitFormTwig(array $request) {
        $this->gateway->insert($request["name"], $request["description"]);
        try {
            $results = $this->gateway->listResults();
            echo $this->twig->render('display_results.html.twig', ['results' => $results]);
        } catch (LoaderError | RuntimeError | SyntaxError $e) {
            echo "Twig error: $e";
        }
    }
}