<?php

namespace App\Gateway;

use App\Connexion;
use App\Data\TacticInfo;
use \PDO;

class TacticInfoGateway {
    private Connexion $con;

    /**
     * @param Connexion $con
     */
    public function __construct(Connexion $con) {
        $this->con = $con;
    }

    public function get(int $id): TacticInfo {
        $row = $this->con->fetch(
            "SELECT * FROM TacticInfo WHERE id = :id",
            [":id" => [$id, PDO::PARAM_INT]]
        )[0];

        return new TacticInfo($id, $row["name"], strtotime($row["creation_date"]));
    }

    public function insert(string $name): TacticInfo {
        $row = $this->con->fetch(
            "INSERT INTO TacticInfo(name, creation_date) VALUES(:name, CURRENT_TIMESTAMP) RETURNING id, creation_date",
            [":name" => [$name, PDO::PARAM_STR]]
        )[0];
        return new TacticInfo(intval($row["id"]), $name, strtotime($row["creation_date"]));
    }

    public function update(int $id, string $name) {
        $this->con->exec(
            "UPDATE TacticInfo SET name = :name WHERE id = :id",
            [
                ":name" => [$name, PDO::PARAM_STR],
                ":id" => [$id, PDO::PARAM_INT]
            ]
        );
    }

}